@@ -3,9 +3,23 @@ import numpy as np
 
 import XDMFWrite_h5py as xh
 
-coor = np.array([[0, 0], [0, 1], [0, 2], [1, 0], [1, 1], [1, 2]])
+coor = np.array(
+    [
+        [0, 0],
+        [0, 1],
+        [0, 2],
+        [1, 0],
+        [1, 1],
+        [1, 2],
+    ]
+)
 
-conn = np.array([[0, 1, 4, 3], [1, 2, 5, 4]])
+conn = np.array(
+    [
+        [0, 1, 4, 3],
+        [1, 2, 5, 4],
+    ]
+)
 
 stress = np.array([1.0, 2.0])
 
